import { useStorage } from '@vueuse/core';
import { defineStore } from 'pinia'
import { useAPI } from './api';

interface State {
    Token: string | null
    User: string | null
    Budgets: Map<string, Budget>,
}

export interface Budget {
    ID: string
    Name: string
    AvailableBalance: number
}

export const useSessionStore = defineStore('session', {
    state: () => useStorage<State>('session', {
        Token: null,
        User: null,
        Budgets: new Map<string, Budget>(),
    }),
    getters: {
        BudgetsList: (state) => [ ...state.Budgets.values() ],
        AuthHeaders: (state) => ({'Authorization': 'Bearer ' + state.Token}),
        LoggedIn: (state) => state.Token != null,
    },
    actions: {
        setTitle(title : string) {
            document.title = "Budgeteer - " + title;
        },
        loginSuccess(x : any) {
            this.User = x.User;
            this.Token = x.Token;
            this.Budgets = x.Budgets;
        },
        async login(login: any) {
            const api = useAPI();
            const response = await api.POST("/user/login", JSON.stringify(login));
            const result = await response.json();
            return this.loginSuccess(result);
        },
        async register(login : any) {
            const api = useAPI();
            const response = await api.POST("/user/register", JSON.stringify(login));
            const result = await response.json();
            return this.loginSuccess(result);
        },
        logout() {
            this.$reset()
        },
    }
})